==> dav1d-doc-1.0.0-1-aarch64.pkg.tar.xz: usr/share/doc/dav1d/html/search/variables_2.js <==
var searchData=
[
  ['callback_0',['callback',['../structDav1dLogger.html#af41e969ab025dba0c309d55b74f6899e',1,'Dav1dLogger']]],
  ['cdef_1',['cdef',['../structDav1dSequenceHeader.html#afbafe2d6fa1de83088321da81925e399',1,'Dav1dSequenceHeader::cdef()'],['../structDav1dFrameHeader.html#a16493e306bc2f45c1267601db29ff6c0',1,'Dav1dFrameHeader::cdef()']]],
  ['chr_2',['chr',['../structDav1dSequenceHeader.html#a136f54030b8c14a34b0db2138858ba48',1,'Dav1dSequenceHeader']]],
  ['chroma_5fscaling_5ffrom_5fluma_3',['chroma_scaling_from_luma',['../structDav1dFilmGrainData.html#a90152508c5134b00c0d831589261099b',1,'Dav1dFilmGrainData']]],
  ['clip_5fto_5frestricted_5frange_4',['clip_to_restricted_range',['../structDav1dFilmGrainData.html#ad3250f9fae32dfcd2424a3223bfcc6db',1,'Dav1dFilmGrainData']]],
  ['col_5fstart_5fsb_5',['col_start_sb',['../structDav1dFrameHeader.html#a493ffd6aa3c1a78fed19a1601e6992c5',1,'Dav1dFrameHeader']]],
  ['color_5fdescription_5fpresent_6',['color_description_present',['../structDav1dSequenceHeader.html#a5ad321eef618d3bbbb4df241c05b03ff',1,'Dav1dSequenceHeader']]],
  ['color_5frange_7',['color_range',['../structDav1dSequenceHeader.html#aea959c56c6d0aba064c61c3575b20143',1,'Dav1dSequenceHeader']]],
  ['cols_8',['cols',['../structDav1dFrameHeader.html#aeef330d77edf21697fdaa69468ee780b',1,'Dav1dFrameHeader']]],
  ['content_5flight_9',['content_light',['../structDav1dPicture.html#a2919a6346d21afa324123f5996904f06',1,'Dav1dPicture']]],
  ['content_5flight_5fref_10',['content_light_ref',['../structDav1dPicture.html#a436c7246d13c39d0759f958ba535404d',1,'Dav1dPicture']]],
  ['cookie_11',['cookie',['../structDav1dLogger.html#a14a83f6d6d6dc394682e49fa3954df15',1,'Dav1dLogger::cookie()'],['../structDav1dPicAllocator.html#abdc461fb2d4c3cfaff113afecc31dfa4',1,'Dav1dPicAllocator::cookie()']]],
  ['country_5fcode_12',['country_code',['../structDav1dITUTT35.html#ab2d558e976eeace342c0fa73871026e4',1,'Dav1dITUTT35']]],
  ['country_5fcode_5fextension_5fbyte_13',['country_code_extension_byte',['../structDav1dITUTT35.html#a13e109e34763949327d4032c148cd14f',1,'Dav1dITUTT35']]]
];

==> dav1d-doc-1.2.1-1-aarch64.pkg.tar.xz: usr/share/doc/dav1d/html/search/variables_2.js <==
var searchData=
[
  ['callback_0',['callback',['../structDav1dLogger.html#af41e969ab025dba0c309d55b74f6899e',1,'Dav1dLogger']]],
  ['cdef_1',['cdef',['../structDav1dSequenceHeader.html#afbafe2d6fa1de83088321da81925e399',1,'Dav1dSequenceHeader::cdef'],['../structDav1dFrameHeader.html#a16493e306bc2f45c1267601db29ff6c0',1,'Dav1dFrameHeader::cdef']]],
  ['chr_2',['chr',['../structDav1dSequenceHeader.html#a136f54030b8c14a34b0db2138858ba48',1,'Dav1dSequenceHeader']]],
  ['chroma_5fscaling_5ffrom_5fluma_3',['chroma_scaling_from_luma',['../structDav1dFilmGrainData.html#a90152508c5134b00c0d831589261099b',1,'Dav1dFilmGrainData']]],
  ['clip_5fto_5frestricted_5frange_4',['clip_to_restricted_range',['../structDav1dFilmGrainData.html#ad3250f9fae32dfcd2424a3223bfcc6db',1,'Dav1dFilmGrainData']]],
  ['col_5fstart_5fsb_5',['col_start_sb',['../structDav1dFrameHeader.html#a493ffd6aa3c1a78fed19a1601e6992c5',1,'Dav1dFrameHeader']]],
  ['color_5fdescription_5fpresent_6',['color_description_present',['../structDav1dSequenceHeader.html#a5ad321eef618d3bbbb4df241c05b03ff',1,'Dav1dSequenceHeader']]],
  ['color_5frange_7',['color_range',['../structDav1dSequenceHeader.html#aea959c56c6d0aba064c61c3575b20143',1,'Dav1dSequenceHeader']]],
  ['cols_8',['cols',['../structDav1dFrameHeader.html#aeef330d77edf21697fdaa69468ee780b',1,'Dav1dFrameHeader']]],
  ['content_5flight_9',['content_light',['../structDav1dPicture.html#a2919a6346d21afa324123f5996904f06',1,'Dav1dPicture']]],
  ['content_5flight_5fref_10',['content_light_ref',['../structDav1dPicture.html#a436c7246d13c39d0759f958ba535404d',1,'Dav1dPicture']]],
  ['cookie_11',['cookie',['../structDav1dLogger.html#a14a83f6d6d6dc394682e49fa3954df15',1,'Dav1dLogger::cookie'],['../structDav1dPicAllocator.html#abdc461fb2d4c3cfaff113afecc31dfa4',1,'Dav1dPicAllocator::cookie']]],
  ['country_5fcode_12',['country_code',['../structDav1dITUTT35.html#ab2d558e976eeace342c0fa73871026e4',1,'Dav1dITUTT35']]],
  ['country_5fcode_5fextension_5fbyte_13',['country_code_extension_byte',['../structDav1dITUTT35.html#a13e109e34763949327d4032c148cd14f',1,'Dav1dITUTT35']]]
];
